@@ -15,7 +15,7 @@ class EnviarPedido(Enviar):
         self.exige_autenticacao = True
         self.processa_resposta = True
         self.url = "https://api.mercadolibre.com/checkout/preferences"
-        self.grava_identificador = True
+        self.deve_gravar_dados_de_pagamento = True
         self.formato_de_envio = FormatoDeEnvio.json
 
     def gerar_dados_de_envio(self):
