@@ -43,7 +43,7 @@ class Registro(RegistroBase):
     @property
     def pedido_numero(self):
         if self.retorno_de_notificacao:
-            return self.dados["collection"]["external_reference"]
+            return self.item_topico["external_reference"]
         if "external_reference" in self.dados:
             return self.dados["external_reference"]
         return None
@@ -103,6 +103,19 @@ class Registro(RegistroBase):
             return False
         return self.topico is not None
 
+    @property
+    def deve_gravar_dados_de_pagamento(self):
+        return self.obter_dados_do_gateway
+
+    @property
+    def valores_de_pagamento(self):
+        valores = {
+            "transacao_id": self.item_topico["id"]
+        }
+        if "total_paid_amount" in self.item_topico:
+            valores["valor_pago"] = self.item_topico["total_paid_amount"]
+        return valores
+
     @property
     def chave_topico(self):
         if self.topico == Topicos.pagamento:
